pub struct Input {
pub patient: FHIRId,
pub name: FHIRCode,
}Fields
patient: FHIRIdThe id of a patient resource located on the server on which this operation is executed
name: FHIRCodeThe code for the functional list that is being found